@@ -353,6 +353,8 @@ class VtkRemoteLocalView(HtmlElement):
 
         activate_module_for(self.server, view)
 
+        MODULE.has_capabilities("web", "rendering")
+
         __ns = kwargs.get("namespace", "view")
         self.__mode_key = f"{__ns}Mode"
         self.__scene_id = f"{__ns}Scene"
@@ -525,6 +527,8 @@ class VtkRemoteView(HtmlElement):
 
         activate_module_for(self.server, view)
 
+        MODULE.has_capabilities("web", "rendering")
+
         self.__view = view
         self.__ref = ref
         self.__view_key_id = f"{ref}Id"
@@ -630,6 +634,9 @@ class VtkLocalView(HtmlElement):
 
         activate_module_for(self.server, view)
 
+        MODULE.has_capabilities("web")
+
+        self._progressive_state = False
         self.__scene_id = f"scene_{ref}"
         self.__view = view
         self.__ref = ref
@@ -687,13 +694,25 @@ class VtkLocalView(HtmlElement):
             "EndInteraction",
         ]
         self.update()
-        self._server.controller.on_server_ready.add(self.update)
+        self._server.controller.on_server_ready.add(self._ready)
+
+    def _ready(self, **kwargs):
+        self.progressive_state(False)
+        self.progressive_state(True)
 
     def update(self, **kwargs):
         """
         Force geometry to be pushed
         """
-        self.server.state[self.__scene_id] = MODULE.scene(self.__view)
+        self.server.state[self.__scene_id] = MODULE.scene(
+            self.__view,
+            new_state=not self._progressive_state,
+        )
+
+    def progressive_state(self, value=True):
+        self._progressive_state = value
+        if not value:
+            self.update()
 
     def reset_camera(self, **kwargs):
         """
